import { Component, For, Show, createSignal } from "solid-js";

import GroupItem from '../components/GroupItem'

import styles from './Groups.module.css';
import { useNavigate } from "@solidjs/router";
import { Group, api } from "../api";
import { localState, showMessageDialog } from "../state";
import { errorToString } from "../util";

const Groups: Component = () => {
	const navigate = useNavigate();

	const [loading, setLoading] = createSignal(true);
	const [groups, setGroups] = createSignal([] as Group[]);

	(async () => {
		try {
			if (localState.accountInfo == null) return;
			setGroups(await api().getGroups());
			setLoading(false);
		} catch (e) {
			showMessageDialog('Failed to load groups', errorToString(e));
		}
	})();

	const createGroup = async () => {
		try {
			const group = await api().createGroup({ name: localState.accountInfo!.user.displayName + "'s group" });
			navigate('/group/' + group.id);
		} catch (e) {
			showMessageDialog('Failed to create group', errorToString(e))
		}

	};

	return (
		<Show when={!loading()} fallback={<div>Loading...</div>}>
			<div class={styles.page}>
				<h1>Your Groups</h1>
				<button onclick={createGroup}>Create Group</button>
				<hr />
				<div class={styles.groups}>
					<For each={groups()}>
						{g => <GroupItem group={g} />}
					</For>
				</div>
			</div>
		</Show >
	)
}

export default Groups;
